from datetime import datetime, timedelta
from server.mock.schemas import TokenUser, TokenShop
from jose import JWTError, jwt
# from main import TokenData


SECRET_KEY = "09d25e094faa6ca2556c818166b7a9563b93f7099f6f0f4caa6cf63b88e8d3e7"
ALGORITHM = "HS256"
ACCESS_TOKEN_EXPIRE_MINUTES = 60

def create_access_token(data: dict):
    to_encode = data.copy()
    expire = datetime.utcnow() + timedelta(minutes=ACCESS_TOKEN_EXPIRE_MINUTES)
    to_encode.update({"exp": expire})
    encoded_jwt = jwt.encode(to_encode, SECRET_KEY, algorithm=ALGORITHM)
    return encoded_jwt

def verify_token(token:str,credentials_exception):
	try:
		payload = jwt.decode(token, SECRET_KEY, algorithms=[ALGORITHM])
		username: str = payload.get("username")
		email: str = payload.get("email")
		if username is None:
			raise credentials_exception
		token_data = TokenUser(username=username, email=email)
		return token_data
	except JWTError:
	    return {"error": "Invalid token"} 

def verify_shop_token(token:str,credentials_exception):
    try:
        payload = jwt.decode(token,SECRET_KEY, algorithms=[ALGORITHM])
        id: str = payload.get("id")
        name: str = payload.get("name")
        owner: str = payload.get("owner")
        if id is None:
            raise credentials_exception
        token_data = TokenShop(id=id, name=name, owner=owner)
        return token_data
    except JWTError:
        return {"error":"Invalid token"}